svn commit: r310760 - in head/sys/dev/sfxge: . common

Andrew Rybchenko arybchik at FreeBSD.org
Thu Dec 29 07:20:54 UTC 2016


Author: arybchik
Date: Thu Dec 29 07:20:53 2016
New Revision: 310760
URL: https://svnweb.freebsd.org/changeset/base/310760

Log:
  sfxge(4): fix typo in pseudo header accessor function names
  
  Sponsored by:   Solarflare Communications, Inc.
  MFC after:      2 days

Modified:
  head/sys/dev/sfxge/common/efx.h
  head/sys/dev/sfxge/common/efx_rx.c
  head/sys/dev/sfxge/sfxge_rx.c

Modified: head/sys/dev/sfxge/common/efx.h
==============================================================================
--- head/sys/dev/sfxge/common/efx.h	Thu Dec 29 07:11:20 2016	(r310759)
+++ head/sys/dev/sfxge/common/efx.h	Thu Dec 29 07:20:53 2016	(r310760)
@@ -1920,7 +1920,7 @@ efx_rx_scale_key_set(
 	__in		size_t n);
 
 extern	__checkReturn	uint32_t
-efx_psuedo_hdr_hash_get(
+efx_pseudo_hdr_hash_get(
 	__in		efx_rxq_t *erp,
 	__in		efx_rx_hash_alg_t func,
 	__in		uint8_t *buffer);
@@ -1928,7 +1928,7 @@ efx_psuedo_hdr_hash_get(
 #endif	/* EFSYS_OPT_RX_SCALE */
 
 extern	__checkReturn	efx_rc_t
-efx_psuedo_hdr_pkt_length_get(
+efx_pseudo_hdr_pkt_length_get(
 	__in		efx_rxq_t *erp,
 	__in		uint8_t *buffer,
 	__out		uint16_t *pkt_lengthp);

Modified: head/sys/dev/sfxge/common/efx_rx.c
==============================================================================
--- head/sys/dev/sfxge/sfxge_rx.c	Thu Dec 29 07:11:20 2016	(r310759)
+++ head/sys/dev/sfxge/sfxge_rx.c	Thu Dec 29 07:20:53 2016	(r310760)
@@ -345,7 +345,7 @@ sfxge_rx_deliver(struct sfxge_rxq *rxq, 
 
 	if (flags & (EFX_PKT_IPV4 | EFX_PKT_IPV6)) {
 		m->m_pkthdr.flowid =
-			efx_psuedo_hdr_hash_get(rxq->common,
+			efx_pseudo_hdr_hash_get(rxq->common,
 						EFX_RX_HASHALG_TOEPLITZ,
 						mtod(m, uint8_t *));
 		/* The hash covers a 4-tuple for TCP only */
@@ -680,7 +680,7 @@ sfxge_lro(struct sfxge_rxq *rxq, struct 
 	unsigned bucket;
 
 	/* Get the hardware hash */
-	conn_hash = efx_psuedo_hdr_hash_get(rxq->common,
+	conn_hash = efx_pseudo_hdr_hash_get(rxq->common,
 					    EFX_RX_HASHALG_TOEPLITZ,
 					    mtod(m, uint8_t *));
 
@@ -843,7 +843,7 @@ sfxge_rx_qcomplete(struct sfxge_rxq *rxq
 		if (rx_desc->flags & EFX_PKT_PREFIX_LEN) {
 			uint16_t tmp_size;
 			int rc;
-			rc = efx_psuedo_hdr_pkt_length_get(rxq->common,
+			rc = efx_pseudo_hdr_pkt_length_get(rxq->common,
 							   mtod(m, uint8_t *),
 							   &tmp_size);
 			KASSERT(rc == 0, ("cannot get packet length: %d", rc));


More information about the svn-src-all mailing list
--- head/sys/dev/sfxge/common/efx_rx.c	Thu Dec 29 07:11:20 2016	(r310759)
+++ head/sys/dev/sfxge/common/efx_rx.c	Thu Dec 29 07:20:53 2016	(r310760)
@@ -540,7 +540,7 @@ efx_rx_qdestroy(
 }
 
 	__checkReturn	efx_rc_t
-efx_psuedo_hdr_pkt_length_get(
+efx_pseudo_hdr_pkt_length_get(
 	__in		efx_rxq_t *erp,
 	__in		uint8_t *buffer,
 	__out		uint16_t *lengthp)
@@ -555,7 +555,7 @@ efx_psuedo_hdr_pkt_length_get(
 
 #if EFSYS_OPT_RX_SCALE
 	__checkReturn	uint32_t
-efx_psuedo_hdr_hash_get(
+efx_pseudo_hdr_hash_get(
 	__in		efx_rxq_t *erp,
 	__in		efx_rx_hash_alg_t func,
 	__in		uint8_t *buffer)
@@ -949,11 +949,11 @@ fail1:
 #endif
 
 /*
- * Falcon/Siena psuedo-header
+ * Falcon/Siena pseudo-header
  * --------------------------
  *
  * Receive packets are prefixed by an optional 16 byte pseudo-header.
  * The psuedo-header is a byte array of one of the forms:
  *
  *  0  1  2  3  4  5  6  7  8  9 10 11 12 13 14 15
  * xx.xx.xx.xx.xx.xx.xx.xx.xx.xx.xx.xx.TT.TT.TT.TT
@@ -949,11 +949,11 @@ fail1:
  *
  * Receive packets are prefixed by an optional 16 byte pseudo-header.
- * The psuedo-header is a byte array of one of the forms:
+ * The pseudo-header is a byte array of one of the forms:
  *
  *  0  1  2  3  4  5  6  7  8  9 10 11 12 13 14 15

Modified: head/sys/dev/sfxge/sfxge_rx.c
==============================================================================